Documentation
¶
Index ¶
- func CreateWorkspace(ctx context.Context, name string, folders []string) error
- func DeleteWorkspace(name string) error
- func GetWorkspacePath(name string) string
- func ImportToWorkspace(ctx context.Context, name string, filePath string, dir string) error
- func Save(name string, workspaceConfig Config) error
- func UpsertWorkspace(ctx context.Context, name string, folders []string) error
- type Config
- type Repo
- type Workspace
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateWorkspace ¶
CreateWorkspace creates a workspace YAML file with the given name, and adds all the git repositories found in the specified folders to it.
func DeleteWorkspace ¶
DeleteWorkspace deletes the workspace with the given name.
func GetWorkspacePath ¶
func ImportToWorkspace ¶
ImportToWorkspace imports a set of repositories, given a file with list of repositories to a workspace
Types ¶
type Repo ¶
type Repo struct {
Name string `yaml:"name"`
Path string `yaml:"path"`
RepoType string `yaml:"type"`
Remote string `yaml:"remote"`
}
Repo represents a git repository with its absolute path and remote URL.
Click to show internal directories.
Click to hide internal directories.